==> cartoun-customizer-1.1.3-sources.jar: fr/toutatice/cartoun/customizer/regions/RegionsCustomizer.java <==
package fr.toutatice.cartoun.customizer.regions;

import java.util.Arrays;
import java.util.Map;

import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;

import org.osivia.portal.api.customization.CustomizationContext;
import org.osivia.portal.api.customization.CustomizationModuleMetadatas;
import org.osivia.portal.api.customization.ICustomizationModule;
import org.osivia.portal.api.customization.ICustomizationModulesRepository;
import org.osivia.portal.api.theming.IRenderedRegions;

/**
 * Regions customizer.
 *
 * @author Cédric Krommenhoek
 * @see GenericPortlet
 * @see ICustomizationModule
 */
public class RegionsCustomizer extends GenericPortlet implements ICustomizationModule {

    /** Customizer name. */
    private static final String CUSTOMIZER_NAME = "demo.customizer.regions";
    /** Customization modules repository attribute name. */
    private static final String ATTRIBUTE_CUSTOMIZATION_MODULES_REPOSITORY = "CustomizationModulesRepository";


    /** Customization module metadatas. */
    private final CustomizationModuleMetadatas metadatas;


    /** Customization modules repository. */
    private ICustomizationModulesRepository repository;


    /**
     * Constructor.
     */
    public RegionsCustomizer() {
        super();
        this.metadatas = this.generateMetadatas();
    }


    /**
     * Generate customization module metadatas.
     *
     * @return metadatas
     */
    private CustomizationModuleMetadatas generateMetadatas() {
        final CustomizationModuleMetadatas metadatas = new CustomizationModuleMetadatas();
        metadatas.setName(CUSTOMIZER_NAME);
        metadatas.setModule(this);
        metadatas.setCustomizationIDs(Arrays.asList(IRenderedRegions.CUSTOMIZER_ID));
        return metadatas;
    }


    /**
     * {@inheritDoc}
     */
    @Override
    public void init() throws PortletException {
        super.init();
        this.repository = (ICustomizationModulesRepository) this.getPortletContext().getAttribute(ATTRIBUTE_CUSTOMIZATION_MODULES_REPOSITORY);
        this.repository.register(this.metadatas);
    }


    /**
     * {@inheritDoc}
     */
    @Override
    public void destroy() {
        super.destroy();
        this.repository.unregister(this.metadatas);
    }


    /**
     * {@inheritDoc}
     */
    @Override
    public void customize(String customizationID, CustomizationContext context) {
        final Map<String, Object> attributes = context.getAttributes();
        final IRenderedRegions renderedRegion = (IRenderedRegions) attributes.get(IRenderedRegions.CUSTOMIZER_ATTRIBUTE_RENDERED_REGIONS);

        // Replace default toolbar
        renderedRegion.customizeRenderedRegion("toolbar", "/regions/toolbar.jsp");

        // baniere
        renderedRegion.customizeRenderedRegion("baniere", "/regions/baniere.jsp");

        // Replace default drawer toolbar
        renderedRegion.customizeRenderedRegion("drawer-toolbar", "/regions/drawer-toolbar.jsp");

        // replace default tabs
        renderedRegion.customizeRenderedRegion("tabs", "/regions/tabs.jsp");

        // Remove default search
        renderedRegion.removeRenderedRegion("search");

        // mentions footer
        renderedRegion.customizeRenderedRegion("mentions", "/regions/mentions.jsp");

        // Cartoun : recherche simple et avancee
        renderedRegion.decoratePortletsRegion("simple-search", "/decorators/simple-search-header.jsp", "/decorators/simple-search-footer.jsp");
        renderedRegion.decoratePortletsRegion("advanced-search", "/decorators/advanced-search-header.jsp", "/decorators/advanced-search-footer.jsp");
    }

}

==> cartoun-customizer-1.2.7-sources.jar: fr/toutatice/cartoun/customizer/regions/RegionsCustomizer.java <==
package fr.toutatice.cartoun.customizer.regions;

import java.util.Arrays;
import java.util.Map;

import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;

import org.osivia.portal.api.customization.CustomizationContext;
import org.osivia.portal.api.customization.CustomizationModuleMetadatas;
import org.osivia.portal.api.customization.ICustomizationModule;
import org.osivia.portal.api.customization.ICustomizationModulesRepository;
import org.osivia.portal.api.theming.IRenderedRegions;

/**
 * Regions customizer.
 *
 * @author Cédric Krommenhoek
 * @see GenericPortlet
 * @see ICustomizationModule
 */
public class RegionsCustomizer extends GenericPortlet implements ICustomizationModule {

    /** Customizer name. */
    private static final String CUSTOMIZER_NAME = "demo.customizer.regions";
    /** Customization modules repository attribute name. */
    private static final String ATTRIBUTE_CUSTOMIZATION_MODULES_REPOSITORY = "CustomizationModulesRepository";


    /** Customization module metadatas. */
    private final CustomizationModuleMetadatas metadatas;


    /** Customization modules repository. */
    private ICustomizationModulesRepository repository;


    /**
     * Constructor.
     */
    public RegionsCustomizer() {
        super();
        this.metadatas = this.generateMetadatas();
    }


    /**
     * Generate customization module metadatas.
     *
     * @return metadatas
     */
    private CustomizationModuleMetadatas generateMetadatas() {
        final CustomizationModuleMetadatas metadatas = new CustomizationModuleMetadatas();
        metadatas.setName(CUSTOMIZER_NAME);
        metadatas.setModule(this);
        metadatas.setCustomizationIDs(Arrays.asList(IRenderedRegions.CUSTOMIZER_ID));
        return metadatas;
    }


    /**
     * {@inheritDoc}
     */
    @Override
    public void init() throws PortletException {
        super.init();
        this.repository = (ICustomizationModulesRepository) this.getPortletContext().getAttribute(ATTRIBUTE_CUSTOMIZATION_MODULES_REPOSITORY);
        this.repository.register(this.metadatas);
    }


    /**
     * {@inheritDoc}
     */
    @Override
    public void destroy() {
        super.destroy();
        this.repository.unregister(this.metadatas);
    }


    /**
     * {@inheritDoc}
     */
    @Override
    public void customize(String customizationID, CustomizationContext context) {
        final Map<String, Object> attributes = context.getAttributes();
        final IRenderedRegions renderedRegion = (IRenderedRegions) attributes.get(IRenderedRegions.CUSTOMIZER_ATTRIBUTE_RENDERED_REGIONS);

        // Replace header
        renderedRegion.customizeRenderedRegion("header-metadata", "/header/header-metadata.jsp");

        // Replace default toolbar
        renderedRegion.customizeRenderedRegion("toolbar", "/regions/toolbar.jsp");

        // baniere
        renderedRegion.customizeRenderedRegion("baniere", "/regions/baniere.jsp");

        // Replace default drawer toolbar
        renderedRegion.customizeRenderedRegion("drawer-toolbar", "/regions/drawer-toolbar.jsp");

        // replace default tabs
        renderedRegion.customizeRenderedRegion("tabs", "/regions/tabs.jsp");

        // Remove default search
        renderedRegion.removeRenderedRegion("search");

        // mentions footer
        renderedRegion.customizeRenderedRegion("mentions", "/regions/mentions.jsp");

        // Cartoun : recherche simple et avancee
        renderedRegion.decoratePortletsRegion("simple-search", "/decorators/simple-search-header.jsp", "/decorators/simple-search-footer.jsp");
        renderedRegion.decoratePortletsRegion("advanced-search", "/decorators/advanced-search-header.jsp", "/decorators/advanced-search-footer.jsp");
    }

}
